# numero_nome

## Description 
O pacote numero_nome é usado:

- Somar os valores das letras do nome informado
- Verificar significado do resultado da soma em relação a numerologia

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install numerologia_nome

```bash
pip install numero_nome
```

## Usage

```python
from numero_nome import processamento
processamento.significa_num(processamento.vetor_numero())
```

## Author
Alan Silva Vieira

## License
[MIT](https://choosealicense.com/licenses/mit/)